#This is just a simple example

#we first need to set the coregrowth directory.  I recommend you set
#it in your .bashrc or you set it manually. The command below will
#then look for the dir, assuming the variable is set
import subprocess as sp
coregrowthdir = sp.Popen(['echo $COREGROWTHPATH'], stdout=sp.PIPE, shell=True).communicate()[0].strip()

#Otherwise you should specify the dir manually.  In our case this
#might be
if coregrowthdir=='': coregrowthdir='./../'

#if you set the coregrowthdir manually, e.g. 
#coregrowthdir = '~/coregrowth0.8/', 
#you should also do the same in the coregrowthdir/src/globalvarsX.py
#file where X denotes the version number

#If the coregrowthdir is known we append the source directories to 
#the python path
import sys
sys.path.append(coregrowthdir+'/src/')

#This allows us to load the key variables and modules
import globalvars80 as g
import rout80 as rout
import core80 as core

#The core80 module contains the main function, which calculates
#the evolution
out = core.main()

#this prints something as "XXX iterations needed" and writes down the
#data in the file 'data.dat'

#In computing the evolution, the default parameters (as written down
#in the globalvarsX.py) have been used.  These you can change as follows

g.a0 = 5.0 *g.au#calculate the evolution at 5.0 AU
g.sPini = 1e7#start with 100km size planetesimals
g.fsig = 5.0#at a 10x larger surface density

out1 = core.main(fn_outputtable='data1.dat')
#output dat is stored in data1.dat

#Finally, let's consider the switches
g.doAE = True#turn on atmosphere enhancement effects
g.doFR = False#turn off fragmentation
g.doER = False#.. and erosion
g.doRD = True#.. and radial drift
g.doPG = False#turn off 'growth' of planetesimals among themselves
g.doND = False#turn off drag modification
g.doOL = True#Assume oligarchy
g.doTS = False#turn off turbulent stirring
g.doTD = False#turn off turbulent diffusion

#and run again
out2 = core.main(fn_outputtable='data2.dat')
#output dat is stored in data2.dat

#plot the mass as function of time
#this requires pylab/matplotlib
import pylab as pl
fg = pl.figure()
ax = fg.add_subplot(111)

#sQarr is an array denoting the parameters in which we are
#interested.  These should match the list in the doc/variables file.
sQarr = ['Time', 'Mc']

data = rout.readData(sQarr, fname='data.dat')#this reads data.dat
data1= rout.readData(sQarr, fname='data1.dat')#this reads data1.dat
data2= rout.readData(sQarr, fname='data2.dat')#this reads data2.dat
[Time, Mass] = [data[:,i] for i in range(len(sQarr))]
[Time1, Mass1] = [data1[:,i] for i in range(len(sQarr))]
[Time2, Mass2] = [data2[:,i] for i in range(len(sQarr))]
ax.loglog(Time/g.yr, Mass/g.Mearth, 'k-')
ax.loglog(Time1/g.yr, Mass1/g.Mearth, 'k--')
ax.loglog(Time2/g.yr, Mass2/g.Mearth, c='0.7')
ax.set_xlabel('Time [yr]')
ax.set_ylabel('Protoplanet mass [Mearth]')
ax.legend(['first run (default)', 'second run (5AU; 5xMMSN; 100km plts)', 'third run (switches)'], loc=2)
ax.set_xlim(1e4, 1e7)
ax.set_ylim(1e-3, 1e2)

fg.savefig('example.eps')
pl.close()
