from numpy import *
import sys
import subprocess as sp
#Try to look for coregrowthdir
coregrowthdir = sp.Popen(['echo $COREGROWTHPATH'], stdout=sp.PIPE, shell=True).communicate()[0].strip()
sys.path.append(coregrowthdir+'/src/')
import core80 as core
import rout80 as rout
import globalvars80 as g

def runmain(Fullres, Mdot_ext):
  core.main(Mdot_ext=Mdot_ext)

  data = rout.readData(g.sQarr)
  Qarr = [data[:,i] for i in range(len(g.sQarr))]

  if Fullres:
    return Qarr
  else:
    [Time, Mass] = Qarr
    return max(Mass)


def runAllSfs (sFinis, Mdot_ext):
  Mouts = []
  line = ''
  for sF in sFinis:
    #set the initial fragment size equal to the minimum fragment size
    g.sFini = sF
    g.s_min = sF
    Mout = runmain(0, Mdot_ext)
    Mouts.append(Mout)
    s = '%11.2e' %Mout
    line = line+s
  f.write(line+'\n')


#the external accretion rate function
def Mdot_ext(time):
  tch  = 1e6 *g.yr
  Mtot = 100*g.Mearth
  A0 = Mtot/tch

  return A0*exp(-time/tch)


#Parameters of interest
g.sQarr= ['Time', 'Mc']

#The fragment sizes
sFinis = [1e-1, 3e-1, 1e0, 3.0, 1e1, 3e1, 1e2, 3e2, 1e3, 3e3, 1e4]
#sFinis = [1e-1, 1e0, 1e1, 1e2, 1e3, 1e4]
N = len(sFinis)

#Take the initial embryo mass 0.01 M_earth
g.Mini = 1e-2*g.Mearth

#low fsigd suppress initial surface density in solids (incl. the embryo)
g.fsigd = 0.05

#xi=0.2 gives a slight speedup
g.xi = 0.2
g.vbl  = 1#verbosity level
g.a0   = 5.0*g.au#radius
g.doRD = True
g.doFR = True
g.doOL = False
g.doND = False
g.doTD = False
g.doAE = False
#set the mass fraction of solids in planetesimal 0
g.fsigP= 0

doRuns = True
fname = 'Data/table10.dat'

if doRuns:
  f = open(fname, 'w')
  f.write('# size [cm] (1st row) || Mass [g] \n')
  line = ''
  for sF in sFinis:
    s = '%11.2e' %sF
    line = line+s
  f.write(line+'\n')

  #compute the first series of models
  runAllSfs(sFinis, Mdot_ext)

  g.doAE = True
  g.doND = True
  runAllSfs(sFinis, Mdot_ext)

  g.doTD = True
  g.doTS = True
  runAllSfs(sFinis, Mdot_ext)

  g.alSS = 1e-3
  runAllSfs(sFinis, Mdot_ext)

  f.close()


print('|====================================================')
print('|')
print('| Now trying to plot data. This may or may not work  ')
print('| depending on your matplotlib availibility/settings ')
print('|')
print('|====================================================')
import pylab as pl
fg3 = pl.figure()
ax3 = fg3.add_subplot(111)

data = loadtxt(fname)

Marr1 = data[1,:]
Marr2 = data[2,:]
Marr3 = data[3,:]
Marr4 = data[4,:]

ax3.loglog(sFinis, Marr1/g.Mearth, 'kx-')
ax3.loglog(sFinis, Marr2/g.Mearth, 'ko--', zorder=3)
ax3.loglog(sFinis, Marr3/g.Mearth, 's-', c='0.6', mfc='0.6', mec='0.6', zorder=2)
ax3.loglog(sFinis, Marr4/g.Mearth, 's-', c='0.6', mfc='0.6', mec='0.6', zorder=2)

ax3.text(0.15, 5, '$\\alpha_\\mathrm{ss} = 10^{-4}$', rotation=60)
ax3.text(0.5, 0.7, '$\\alpha_\\mathrm{ss} = 10^{-3}$', rotation=50)

ax3.legend(['(default)','+AE,ND','+TD'], loc=9)
ax3.set_xlabel('Size of drifting fragments [cm]')
ax3.set_ylabel('Accretion efficiency [\%] or final $M_E$ [$M_\\oplus$]')
ax3.set_ylim(1e-1,1e2)
fg3.savefig('fig10.eps')

pl.close()

