#file containing all parameters.  These values approximately correspond to Fig
#XXX of OKXX
#See the parameters.txt file for a description of each parameter
import subprocess as sp

#try to look for the main dir
#this can result in an empty string ('') in which case the code must be run from the installation directory
#alternatively, maindir can be specified manually, but this must be consistent with your main program
coregrowthdir = sp.Popen(['echo $COREGROWTHPATH'], stdout=sp.PIPE, shell=True).communicate()[0].strip()
if coregrowthdir=='': coregrowthdir='./../'#when run from the example dir

#Physical constants
#the units are cgs
au = 1.49598e13#1 AU in cm
yr = 3.15576e7#1 year in seconds
Msun = 1.98892e33#1 solar mass in grams
Mearth = 5.9736e27#1 earth mass in grams
amu = 1.660538782e-24#atomic mass unit (grams)
Gn = 6.67428e-8#Gravitational constant (cgs)
kB = 1.3806504e-16#Boltzmann constant (cgs)
sB = 5.6704e-5#Stefan-Boltzmann constant (cgs)
gamAd = 1.4#adiabatic index of gas

#disk parameters
#turbulent stirring parameter (alSS)
a0 = 5*au
fsigd = 1.0#enhancement surface density over MMSN
fsig = 1.0
vhw = 54e2#the headwind
Mstar = Msun
alSS = 1e-4
sPini = 10e5
sFini = -1# if this is -1 we calculate the initial fragment size
fsigP = 1.0#fraction of mass initially in planetesimals, rather than fragments

#switches (9 in total)
#these are described in the documents
doAE = False
doBO = False
doND = False
doER = True
doFR = True
doOL = True
doPG = True
doRD = True
doTS = False
doTD = False

#choose a model for the inclination i
#of the planetesimal bodies
#TBD: remove this feature; it is in any case not supported!
incMode = 'eq'#i:e = 0.5 (the default)

#Use the mmsn model or not (Y/N)
useMmsn = True
#If this is false an input file has to be provided with the density and
#temperature structure The default name of this file is
physparName = 'physpar'

#constants
btwig = 2**(1./3) *10.0# the separation in terms of Hill radii
Ccol = 36.
ehsd = 1.0#transition to shear-dom; TBD: may remove this
Pvs2d = 73#TBD! change name to Pvs2D
eh1 = 2.34
mu = 2.34*amu
kappa = 0.01#for the atmospheres
Cdriftfac = 0.5# constant that sets the (effective) drift length to be a fraction of the s.m.a
cofr = 0.0#coefficient of restitution (in terms of energy; 1 for fully elastic; 0 for inelastic)
Tdisp = 1e99#depletion timescale !TBD: change to Tdisp

#computational (control) parameters
tol = 1e-4
xi = 0.1
ehmin = 1e-8#absolute lower minimum for eh
ehmax = 1e3#!TBD do we still use this?
fsigmin = 1e-10#!TBD: or this? limit of surface density distribution to follow with respect to initial (Sigini)
vbl = 1#verbose level
#sQarr = variablesDict.keys()
sQarr = ['modeP', 'Time', 'Mc', 'ehP', 'sP', 'sF', 'sigP', 'sigF']

#(default) initialization pars
Tini = 0
Tend = 1e7*yr
Mini = 1e-6*Mearth

#material parameters
rhos = 1.0
rhoc = 1.0
s_min = 1e0#cm; minimum size of the fragments TBD:Maybe rename to smin?
#if parameters are put -1, they are specified in main program
Q0s = -1.0
Q0g = -1.0
bs  = -1.0
bg  = -1.0
Cgg = -1.0
#Using this parameters file
mparfile = 'ice'

#Disk constants
SigGini = -1.0
SigTini = -1.0
rhog0   = -1.0
Om0     = -1.0
cs      = -1.0
Tneb    = -1.0

#target qF for fragments
qFfrag = 0.5
